@@ -80,7 +80,7 @@ class Packet(ctypes.LittleEndianStructure, PacketMixin):
     _pack_ = 1
 
     def __repr__(self):
-        return self.to_json()
+        return str(self.to_dict())
 
 
 # [[[cog
